pub struct AuthConfig {
pub auth: Option<String>,
pub email: Option<String>,
pub identitytoken: Option<String>,
pub password: Option<String>,
pub registrytoken: Option<String>,
pub serveraddress: Option<String>,
pub username: Option<String>,
}Expand description
AuthConfig contains authorization information for connecting to a Registry
Fields
auth: Option<String>email: Option<String>Email is an optional value associated with the username. This field is deprecated and will be removed in a later version of docker.
identitytoken: Option<String>IdentityToken is used to authenticate the user and get an access token for the registry.
password: Option<String>registrytoken: Option<String>RegistryToken is a bearer token to be sent to a registry
serveraddress: Option<String>username: Option<String>Implementations
Sourceimpl AuthConfig
impl AuthConfig
pub fn new() -> AuthConfig