pub struct ConnectionAuthPendingMetadata {
pub client_version: Option<String>,
pub connection_id: String,
pub environment: Option<HashMap<String, MetadataValue>>,
pub files: Option<HashMap<String, BinaryMetadataValue>>,
pub metadata: Option<HashMap<String, MetadataValue>>,
pub remote_address: String,
pub username: String,
}Expand description
ConnectionAuthPendingMetadata is a variant of ConnectionMetadata which is used when the client has already provided a Username, but the authentication has not completed yet.
Fields
client_version: Option<String>ClientVersion contains the version string the connecting client sent if any. May be empty if the client did not provide a client version.
connection_id: StringConnectionID is an opaque ID to identify the SSH connection in question.
environment: Option<HashMap<String, MetadataValue>>Environment is a set of key-value pairs provided by the authentication or configuration system and may be exposed by the backend.
files: Option<HashMap<String, BinaryMetadataValue>>Files is a key-value pair of file names and their content set by the authentication or configuration system and consumed by the backend.
metadata: Option<HashMap<String, MetadataValue>>Metadata is a set of key-value pairs that carry additional information from the authentication and configuration system to the backends. Backends can expose this information as container labels, environment variables, or other places.
remote_address: StringRemoteAddress is the IP address and port of the user trying to authenticate.
username: StringUsername is the username provided on login by the client. This may, but must not necessarily match the authenticated username.
Implementations