pub struct ConnectionAuthenticatedMetadata {
pub authenticated_username: Option<String>,
pub client_version: Option<String>,
pub connection_id: String,
pub environment: Option<HashMap<String, MetadataValue>>,
pub files: Option<HashMap<String, BinaryMetadataValue>>,
pub metadata: Option<HashMap<String, MetadataValue>>,
pub remote_address: String,
pub username: String,
}Expand description
ConnectionAuthenticatedMetadata is a variant of ConnectionMetadata which is used once the authentication has been completed. It contains the AuthenticatedUsername provided by the authentication system.
Fields
authenticated_username: Option<String>AuthenticatedUsername contains the username that was actually verified. This may differ from LoginUsername when, for example OAuth2 or Kerberos authentication is used. This field is empty until the authentication phase is completed.
client_version: Option<String>ClientVersion contains the version string the connecting client sent if any. May be empty if the client did not provide a client version.
connection_id: StringConnectionID is an opaque ID to identify the SSH connection in question.
environment: Option<HashMap<String, MetadataValue>>Environment is a set of key-value pairs provided by the authentication or configuration system and may be exposed by the backend.
files: Option<HashMap<String, BinaryMetadataValue>>Files is a key-value pair of file names and their content set by the authentication or configuration system and consumed by the backend.
metadata: Option<HashMap<String, MetadataValue>>Metadata is a set of key-value pairs that carry additional information from the authentication and configuration system to the backends. Backends can expose this information as container labels, environment variables, or other places.
remote_address: StringRemoteAddress is the IP address and port of the user trying to authenticate.
username: StringUsername is the username provided on login by the client. This may, but must not necessarily match the authenticated username.
Implementations