FileMode

Struct FileMode 

pub struct FileMode(/* private fields */);
The bits have the same definition on all systems, so that information about files can be moved from one system to another portably. Not all bits apply to all systems. The only required bit is ModeDir for directories.

Methods from Deref<Target = i32>

1.43.0 · Source

pub const MIN: i32

1.43.0 · Source

pub const MAX: i32

1.53.0 · Source

pub const BITS: u32 = u32::BITS