pub struct HttpClientConfiguration {
pub allow_redirects: Option<bool>,
pub cacert: Option<String>,
pub cert: Option<String>,
pub cipher: Option<Vec<CipherSuite>>,
pub curves: Option<Vec<EcdhCurve>>,
pub key: Option<String>,
pub timeout: Option<i64>,
pub tls_version: Option<String>,
pub url: Option<String>,
}Expand description
HTTPClientConfiguration is the configuration structure for HTTP clients
Fields
allow_redirects: Option<bool>AllowRedirects sets if the client should honor HTTP redirects. Defaults to false.
cacert: Option<String>CACert is either the CA certificate to expect on the server in PEM format or the name of a file containing the PEM.
cert: Option<String>ClientCert is a PEM containing an x509 certificate to present to the server or a file name containing the PEM.
cipher: Option<Vec<CipherSuite>>curves: Option<Vec<EcdhCurve>>ECDHCurveList is a list of supported ECDHCurve
key: Option<String>ClientKey is a PEM containing a private key to use to connect the server or a file name containing the PEM.
timeout: Option<i64>A Duration represents the elapsed time between two instants as an int64 nanosecond count. The representation limits the largest representable duration to approximately 290 years.
tls_version: Option<String>url: Option<String>URL is the base URL for requests.
Implementations
Sourceimpl HttpClientConfiguration
impl HttpClientConfiguration
pub fn new() -> HttpClientConfiguration