pub struct ConnectionMetadata {
pub connection_id: String,
pub environment: Option<HashMap<String, MetadataValue>>,
pub files: Option<HashMap<String, BinaryMetadataValue>>,
pub metadata: Option<HashMap<String, MetadataValue>>,
pub remote_address: String,
}Expand description
ConnectionMetadata holds a metadata structure passed around with a metadata. Its main purpose is to allow an authentication or authorization module to configure data exposed to the configuration server or the backend.
Fields
connection_id: StringConnectionID is an opaque ID to identify the SSH connection in question.
environment: Option<HashMap<String, MetadataValue>>Environment is a set of key-value pairs provided by the authentication or configuration system and may be exposed by the backend.
files: Option<HashMap<String, BinaryMetadataValue>>Files is a key-value pair of file names and their content set by the authentication or configuration system and consumed by the backend.
metadata: Option<HashMap<String, MetadataValue>>Metadata is a set of key-value pairs that carry additional information from the authentication and configuration system to the backends. Backends can expose this information as container labels, environment variables, or other places.
remote_address: StringRemoteAddress is the IP address and port of the user trying to authenticate.
Implementations
Sourceimpl ConnectionMetadata
impl ConnectionMetadata
pub fn new(connection_id: String, remote_address: String) -> ConnectionMetadata